# cPyparsing

[Cython](http://cython.org/) implementation of [PyParsing](http://pyparsing.wikispaces.com/) created for use in [Coconut](http://coconut-lang.org/) and [Undebt](https://github.com/Yelp/undebt).

Just `pip install cpyparsing` then `import cPyparsing as pyparsing` or otherwise use `cPyparsing` however you would normally use `pyparsing`.

Supported Python versions: `2.6`, `2.7`, `3.3`, `3.4`, `3.5`, `3.6`.
